@@ -23,6 +23,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
@@ -30,8 +31,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
-import javax.servlet.http.HttpServletRequest;
-
 import org.apache.wicket.Application;
 import org.apache.wicket.Component;
 import org.apache.wicket.IConverterLocator;
@@ -40,15 +39,15 @@ import org.apache.wicket.Localizer;
 import org.apache.wicket.WicketRuntimeException;
 import org.apache.wicket.ajax.AjaxRequestTarget;
 import org.apache.wicket.behavior.Behavior;
+import org.apache.wicket.core.request.handler.IPartialPageRequestHandler;
 import org.apache.wicket.core.util.lang.WicketObjects;
 import org.apache.wicket.markup.ComponentTag;
 import org.apache.wicket.markup.html.form.AutoLabelResolver.AutoLabelMarker;
 import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.IObjectClassAwareModel;
 import org.apache.wicket.model.IPropertyReflectionAwareModel;
 import org.apache.wicket.model.Model;
 import org.apache.wicket.request.IRequestParameters;
-import org.apache.wicket.request.Request;
-import org.apache.wicket.request.parameter.EmptyRequestParameters;
 import org.apache.wicket.util.convert.ConversionException;
 import org.apache.wicket.util.convert.IConverter;
 import org.apache.wicket.util.lang.Args;
@@ -106,7 +105,7 @@ import org.slf4j.LoggerFactory;
  * 
  */
 public abstract class FormComponent<T> extends LabeledWebMarkupContainer implements
-	IFormVisitorParticipant, IFormModelUpdateListener, IGenericComponent<T>
+	IFormVisitorParticipant, IFormModelUpdateListener, IGenericComponent<T, FormComponent<T>>
 {
 	private static final Logger logger = LoggerFactory.getLogger(FormComponent.class);
 
@@ -119,18 +118,15 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 	{
 		private final Set<String> triedKeys = new LinkedHashSet<>();
 
-		/**
-		 * @see org.apache.wicket.validation.IErrorMessageSource#getMessage(String, java.util.Map)
-		 */
 		@Override
 		public String getMessage(String key, Map<String, Object> vars)
 		{
 			final FormComponent<T> formComponent = FormComponent.this;
 
-			// Use the following log4j config for detailed logging on the property resolution
-			// process
-			// log4j.logger.org.apache.wicket.resource.loader=DEBUG
-			// log4j.logger.org.apache.wicket.Localizer=DEBUG
+			// Use the following slf4j-simple config for detailed logging
+			// on the property resolution process
+			// org.slf4j.simpleLogger.log.org.apache.wicket.resource.loader=DEBUG
+			// org.slf4j.simpleLogger.log.org.apache.wicket.Localizer=DEBUG
 
 			final Localizer localizer = formComponent.getLocalizer();
 
@@ -306,6 +302,13 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 		}
 	}
 
+	@Override
+	protected void onBeforeRender()
+	{
+		// WICKET-7101 update related auto-label
+		getRequestCycle().find(IPartialPageRequestHandler.class).ifPresent(handler -> updateAutoLabels(handler, true));
+		super.onBeforeRender();
+	}
 
 	/**
 	 * Adapter that makes this component appear as {@link IValidatable}
@@ -639,7 +642,7 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 	/**
 	 * Clears the user input.
 	 */
-	public final void clearInput()
+	public void clearInput()
 	{
 		rawInput = NO_RAW_INPUT;
 	}
@@ -773,12 +776,12 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 		{
 			if (values != null && values.length == 1 && values[0] == null)
 			{
-				// we the key got passed in (otherwise values would be null),
+				// the key got passed in (otherwise values would be null),
 				// but the value was set to null.
 				// As the servlet spec isn't clear on what to do with 'empty'
 				// request values - most return an empty string, but some null -
 				// we have to workaround here and deliberately set to an empty
-				// string if the the component is not nullable (text components)
+				// string if the component is not nullable (text components)
 				return EMPTY_STRING_ARRAY;
 			}
 		}
@@ -796,33 +799,7 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 	 */
 	protected List<StringValue> getParameterValues(String inputName)
 	{
-		String method = Form.METHOD_POST;
-		final Request request = getRequest();
-		if (getRequest().getContainerRequest() instanceof HttpServletRequest)
-		{
-			method = ((HttpServletRequest)getRequest().getContainerRequest()).getMethod();
-		}
-		else
-		{
-			final Form<?> form = findParent(Form.class);
-			if (form != null)
-			{
-				method = form.getMethod();
-			}
-		}
-
-		final IRequestParameters parameters;
-		switch (method.toLowerCase(Locale.ROOT))
-		{
-			case Form.METHOD_POST:
-				parameters = request.getPostParameters();
-				break;
-			case Form.METHOD_GET:
-				parameters = request.getQueryParameters();
-				break;
-			default:
-				parameters = EmptyRequestParameters.INSTANCE;
-		}
+		final IRequestParameters parameters = Form.getRequestParameters(this);
 
 		return parameters.getParameterValues(inputName);
 	}
@@ -977,7 +954,7 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 	 * Gets whether this component's input can be null. By default, components that do not get input
 	 * will have null values passed in for input. However, component TextField is an example
 	 * (possibly the only one) that never gets a null passed in, even if the field is left empty
-	 * UNLESS it had attribute <code>disabled="disabled"</code> set.
+	 * UNLESS it has attribute <code>disabled="disabled"</code> set.
 	 * 
 	 * @return True if this component's input can be null. Returns true by default.
 	 */
@@ -1074,6 +1051,8 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 	}
 
 	/**
+	 * THIS METHOD IS NOT PART OF THE WICKET PUBLIC API. DO NOT USE IT!
+	 *
 	 * Sets the value for a form component.
 	 * 
 	 * @param value
@@ -1430,11 +1409,6 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 			onDisabled(tag);
 		}
 
-		if (isRequired())
-		{
-			onRequired(tag);
-		}
-
 		super.onComponentTag(tag);
 	}
 
@@ -1463,17 +1437,6 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 		tag.put("disabled", "disabled");
 	}
 
-	/**
-	 * Called by {@link #onComponentTag(ComponentTag)} when the component is required.
-	 * 
-	 * @param tag
-	 *            the tag that is being rendered
-	 */
-	@Deprecated
-	protected void onRequired(final ComponentTag tag)
-	{
-	}
-
 	/**
 	 * Handle invalidation
 	 */
@@ -1599,39 +1562,14 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 		return new ValidatableAdapter();
 	}
 
-	@Override
-	@SuppressWarnings("unchecked")
-	public final IModel<T> getModel()
-	{
-		return (IModel<T>)getDefaultModel();
-	}
-
-	@Override
-	public final void setModel(IModel<T> model)
-	{
-		setDefaultModel(model);
-	}
-
-	@SuppressWarnings("unchecked")
-	@Override
-	public final T getModelObject()
-	{
-		return (T)getDefaultModelObject();
-	}
-
-	@Override
-	public final void setModelObject(T object)
-	{
-		setDefaultModelObject(object);
-	}
-
 	/**
 	 * Updates auto label css classes such as error/required during ajax updates when the labels may
 	 * not be directly repainted in the response.
 	 * 
-	 * @param target
+	 * @param target The {@link IPartialPageRequestHandler}
+	 * @param checkAuto if true then we check is the related auto-label is marked as auto before updating it.
 	 */
-	public final void updateAutoLabels(AjaxRequestTarget target)
+	public final void updateAutoLabels(IPartialPageRequestHandler target, boolean checkAuto)
 	{
 		AutoLabelMarker marker = getMetaData(AutoLabelResolver.MARKER_KEY);
 	
@@ -1641,13 +1579,33 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 			return;
 		}
 
+		if (checkAuto)
+		{
+			if (!marker.isAuto())
+			{
+				return;
+			}
+			marker.updateFrom(this, target);
+			return;
+		}
+
 		marker.updateFrom(this, target);
 	}
 
+
+	/**
+	 * @deprecated method in favor of the one receiving {@link IPartialPageRequestHandler}
+	 */
+	@Deprecated(since = "9.17.0, 10.0.0", forRemoval = true)
+	public final void updateAutoLabels(AjaxRequestTarget target)
+	{
+		updateAutoLabels(target, false);
+	}
+
 	/**
 	 * Update the model of a {@link FormComponent} containing a {@link Collection}.
 	 * 
-	 * If the model object does not yet exists, a new {@link ArrayList} is filled with the converted
+	 * If the model object does not yet exists, a new suitable collection is filled with the converted
 	 * input and used as the new model object. Otherwise the existing collection is modified
 	 * in-place, then {@link IModel#setObject(Object)} is called with the same instance: it allows
 	 * the Model to be notified of changes even when {@link Model#getObject()} returns a different
@@ -1671,7 +1629,14 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 		Collection<S> collection = formComponent.getModelObject();
 		if (collection == null)
 		{
-			collection = new ArrayList<>(convertedInput);
+			Class<?> hint = null;
+			if (formComponent.getModel() instanceof IObjectClassAwareModel) {
+				hint = ((IObjectClassAwareModel)formComponent.getModel()).getObjectClass();
+			}
+			if (hint == null) {
+				hint = List.class;
+			}
+			collection = newCollection(hint, convertedInput);
 			formComponent.setModelObject(collection);
 		}
 		else
@@ -1693,7 +1658,7 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 					logger.debug("An error occurred while trying to modify the collection attached to "
 							+ formComponent, unmodifiable);
 				}
-				collection = new ArrayList<>(convertedInput); 
+				collection = newCollection(collection.getClass(), convertedInput);
 			}
 			
 			try
@@ -1717,4 +1682,21 @@ public abstract class FormComponent<T> extends LabeledWebMarkupContainer impleme
 			formComponent.modelChanged();
 		}
 	}
+	
+	/**
+	 * Creates a new collection. 
+	 * 
+	 * @param hint type deciding the type of the returned collection
+	 * @param  elements elements for the new collection
+	 * @return collection
+	 * @throws IllegalArgumentException if type is not supported
+	 */
+	private static <S> Collection<S> newCollection(Class<?> hint, Collection<S> elements)
+	{
+		if (Set.class.isAssignableFrom(hint)) {
+			return new HashSet<>(elements);
+		} else {
+			return new ArrayList<>(elements);
+		}
+	}
 }
