@@ -34,6 +34,7 @@ import java.util.Set;
 import java.util.TimeZone;
 
 import javax.servlet.ServletOutputStream;
+import javax.servlet.WriteListener;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletResponse;
 
@@ -80,8 +81,6 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 
 	private StringWriter stringWriter;
 
-	private final MockHttpServletRequest servletRequest;
-
 	/**
 	 * Create the response object.
 	 * 
@@ -89,7 +88,6 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 	 */
 	public MockHttpServletResponse(MockHttpServletRequest servletRequest)
 	{
-		this.servletRequest = servletRequest;
 		initialize();
 	}
 
@@ -336,6 +334,7 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 	 *            The header name
 	 * @return The value, or null
 	 */
+	@Override
 	@SuppressWarnings("unchecked")
 	public String getHeader(final String name)
 	{
@@ -355,6 +354,7 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 	 * 
 	 * @return The header names
 	 */
+	@Override
 	public Set<String> getHeaderNames()
 	{
 		return headers.keySet();
@@ -402,6 +402,7 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 	 * 
 	 * @return The status code
 	 */
+	@Override
 	public int getStatus()
 	{
 		return status;
@@ -441,6 +442,17 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 		byteStream = new ByteArrayOutputStream();
 		servletStream = new ServletOutputStream()
 		{
+			@Override
+			public boolean isReady()
+			{
+				return true;
+			}
+
+			@Override
+			public void setWriteListener(WriteListener writeListener)
+			{
+			}
+
 			@Override
 			public void write(int b)
 			{
@@ -553,47 +565,6 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 		errorMessage = msg;
 	}
 
-	/**
-	 * @return url
-	 * @see org.apache.wicket.request.Request#getUrl()
-	 */
-	private String getURL()
-	{
-		/*
-		 * Servlet 2.3 specification :
-		 * 
-		 * Servlet Path: The path section that directly corresponds to the mapping which activated
-		 * this request. This path starts with a "/" character except in the case where the request
-		 * is matched with the "/*" pattern, in which case it is the empty string.
-		 * 
-		 * PathInfo: The part of the request path that is not part of the Context Path or the
-		 * Servlet Path. It is either null if there is no extra path, or is a string with a leading
-		 * "/".
-		 */
-		String url = servletRequest.getServletPath();
-		final String pathInfo = servletRequest.getPathInfo();
-
-		if (pathInfo != null)
-		{
-			url += pathInfo;
-		}
-
-		final String queryString = servletRequest.getQueryString();
-
-		if (queryString != null)
-		{
-			url += ("?" + queryString);
-		}
-
-		// If url is non-empty it will start with '/', which we should lose
-		if (url.length() > 0 && url.charAt(0) == '/')
-		{
-			// Remove leading '/'
-			url = url.substring(1);
-		}
-		return url;
-	}
-
 	/**
 	 * Indicate sending of a redirectLocation to a particular named resource. This implementation
 	 * just keeps hold of the redirectLocation info and makes it available for query.
@@ -645,6 +616,12 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 		setIntHeader("Content-Length", length);
 	}
 
+	@Override
+	public void setContentLengthLong(long len)
+	{
+		setContentLength((int) len);
+	}
+
 	/**
 	 * Set the content type.
 	 * 
@@ -838,16 +815,6 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 		setStatus(status);
 	}
 
-	/**
-	 * @deprecated use {@link #getDocument()}
-	 * @return response as String
-	 */
-	@Deprecated
-	public String getTextResponse()
-	{
-		return getDocument();
-	}
-
 	/**
 	 * @return binary response
 	 */
@@ -868,6 +835,7 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 	 * @param name
 	 * @return headers with given name
 	 */
+	@Override
 	public Collection<String> getHeaders(String name)
 	{
 		return Collections.singletonList(headers.get(name).toString());
@@ -886,4 +854,4 @@ public class MockHttpServletResponse implements HttpServletResponse, IMetaDataBu
 		}
 		webResponse.setStatus(status);
 	}
-}
\ No newline at end of file
+}
